## Update Facts

We are working on the following hypothesis:

{current_hypothesis}

It's clear we aren't making as much progress as we would like, but we may have learned something new. Please rewrite the following fact sheet, updating it to include anything new we have learned that may be helpful. Updates may be made to any section of the fact sheet.

Here is the old fact sheet:

{fact_sheet}

